@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2021, QIIME 2 development team.
+# Copyright (c) 2016-2022, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -356,26 +356,6 @@ class CliTests(unittest.TestCase):
 
         self.assertTrue('deprecated' in result.output)
 
-    def test_examples(self):
-        qiime_cli = RootCommand()
-        command = qiime_cli.get_command(ctx=None, name='dummy-plugin')
-        result = self.runner.invoke(
-            command, ['typical-pipeline', '--examples']
-        )
-        self.assertEqual(result.exit_code, 0)
-
-    def test_no_examples(self):
-        qiime_cli = RootCommand()
-        command = qiime_cli.get_command(ctx=None, name='dummy-plugin')
-        result = self.runner.invoke(
-            command, ['unioned-primitives', '--examples']
-        )
-        self.assertEqual(result.exit_code, 0)
-        self.assertEqual(
-            result.output,
-            "No examples have been registered for this action yet.\n"
-        )
-
 
 class TestOptionalArtifactSupport(unittest.TestCase):
     def setUp(self):
